"""
Binance Derivatives Trading Portfolio Margin Pro WebSocket Market Streams

OpenAPI Specification for the Binance Derivatives Trading Portfolio Margin Pro WebSocket Market Streams
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from .risklevelchange import Risklevelchange as Risklevelchange
from .user_data_stream_events_response import (
    UserDataStreamEventsResponse as UserDataStreamEventsResponse,
)
